@@ -29,18 +29,27 @@ from elementpath.datatypes import UntypedAtomic
 from elementpath.namespaces import XSD_NAMESPACE, XPATH_FUNCTIONS_NAMESPACE
 from elementpath.xpath_nodes import AttributeNode, TypedAttribute, \
     TypedElement, NamespaceNode, TextNode
-from elementpath.xpath_token import ordinal, UNICODE_CODEPOINT_COLLATION
+from elementpath.xpath_token import UNICODE_CODEPOINT_COLLATION
+from elementpath.helpers import ordinal
 from elementpath.xpath_context import XPathContext, XPathSchemaContext
 from elementpath.xpath1 import XPath1Parser
 from elementpath.xpath2 import XPath2Parser
-from elementpath.schema_proxy import AbstractXsdType
 
 
-DummyXsdType = type(
-    'XsdType', (AbstractXsdType,),
-    dict(name=None, local_name=None, is_matching=lambda x: False, **{
-        k: lambda x: None for k in AbstractXsdType.__dict__ if k[0] != '_'
-    }))
+class DummyXsdType:
+    name = local_name = None
+
+    def is_matching(self, name, default_namespace): pass
+    def is_empty(self): pass
+    def is_simple(self): pass
+    def has_simple_content(self): pass
+    def has_mixed_content(self): pass
+    def is_element_only(self): pass
+    def is_key(self): pass
+    def is_qname(self): pass
+    def is_notation(self): pass
+    def decode(self, obj, *args, **kwargs): pass
+    def validate(self, obj, *args, **kwargs): pass
 
 
 class Tagged(object):
